<?php
namespace Teknisa\PAR\Controller;

use Teknisa\PAR\Controller\TeknisaCrud;
use Teknisa\PAR\Service\ParceiroNegocioService;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Teknisa\Libs\Util\Environment;

class ParceiroNegocioController extends TeknisaCrud {

    protected $crudService;
    protected $dataSourceName = 'parcnegocio';
    protected $parameterBagColumns = array('IDTPOPERADOR', 'NRREVENDA');
    protected $parceiroService;
    protected $environment;

    public function __construct($crudService, ParameterBag $parameterBag, ParceiroNegocioService $parceiroService, Environment $environment) {
        $this->crudService = $crudService;
        $this->parceiroService = $parceiroService;
        parent::__construct($crudService, $parameterBag);
        $this->environment = $environment;
    }
    
    public function deleteContato(DTO\Request $request, DTO\Response $response){
        $row = $request->getRow();
        $this->parceiroService->deleteContato($row);  
    }
    
    public function findContato(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName = 'relacionaparc_parceiro';
        $this->parameterBagColumns = array('P_NRORG');
        parent::find($request, $response);
    }
    
    public function findRelacionamento(DTO\Request\Filter $request, DTO\Response $response){
        $this->dataSourceName = 'tiporelaciona';
        $this->parameterBagColumns = array();
        parent::find($request, $response);
    }
    
    public function saveContato(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $parcnegocio = $this->parceiroService->saveContato($row);
            
            $columnsToReturn = array(
                "NRPARCNEGOCIO"   => $parcnegocio["NRPARCNEGOCIO"],
                "NRRELACIONAPARC" => $parcnegocio["NRRELACIONAPARC"],
                "NRORG"           => $this->environment->getNrOrg()
            );
            
            $response->addDataset(new DataSet('columnsToReturn', $columnsToReturn));
        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function save(DTO\Request $request, DTO\Response $response) {
        try {
            $row = $request->getRow();
            $nrparcnegocio = $this->parceiroService->saveParceiro($row);
            if ($row['__is_new']) {
                $columnsToReturn = array(
                    "NRPARCNEGOCIO" => $nrparcnegocio,
                    "NRORG"         => $this->environment->getNrOrg()
                );
                
                $response->addDataset(new DataSet('columnsToReturn', $columnsToReturn));
            }
        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    /**
     * A função "completaPercentual" verifica qual o percentual faltante para inserção na página "índices Financeiros Padrões"
     */
    public function completaPercentual(DTO\Request $request, DTO\Response $response) {
        try{
            $row = $request->getRow();
            
            $nrorg = $this->environment->getNrOrg();
            $nrparcnegocio = $row['NRPARCNEGOCIO'];
    
            $result = $this->parceiroService->completaPercentual($nrparcnegocio, $nrorg);
            
            $response->addDataSet(new DataSet("completaPercentual", array("PERCENTUAL" => $result)));

        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    /**
     * A função "validaPercentual" valida o percentual para inserção na página "índices Financeiros Padrões"
     */
    public function validaPercentual(DTO\Request $request, DTO\Response $response) {
        try{
            $row = $request->getRow();
            
            $nrorg = $this->environment->getNrOrg();
            $nrparcnegocio     = $row['NRPARCNEGOCIO'];
            $nrindicespadrparc = $row['NRINDICESPADRPARC'];
    
            $result = $this->parceiroService->validaPercentual($nrparcnegocio, $nrindicespadrparc, $nrorg);
            
            $response->addDataSet(new DataSet("validaPercentual", array("PERCENTUAL" => $result)));

        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    /**
     * A função "saveParamFatura" verifica se existe o registro para o parceiro de negócio enviado. Sendo que:
     *   - Caso não exista, cria o registro. 
     *   - Caso exista, altera o registro.
     */
    public function saveParamFatura(DTO\Request $request, DTO\Response $response) {
        try{
            $row = $request->getRow();
            
            $nrorg = $this->environment->getNrOrg();
            
            $this->parceiroService->saveParamFatura($row, $nrorg);
            
        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    /* recebe os dados de parâmetro de Faturamento */
    public function recebeParamFatura(DTO\Request $request, DTO\Response $response) {
        try{
            $row = $request->getRow();
            
            $nrparcnegocio = $row['NRPARCNEGOCIO'];
            $nrorg = $this->environment->getNrOrg();
    
            $result = $this->parceiroService->recebeParamFatura($nrparcnegocio, $nrorg);
            
            $response->addDataSet(new DataSet("recebeParamFatura", array("dados" => $result)));

        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    /* Valida se existe a forma de comunicação antes da inserção de uma nova forma de comunicação */
    public function validaFormaComunica(DTO\Request $request, DTO\Response $response) {
        try{
            $row = $request->getRow();
            
            $formacomu = $row['CDFORMACOMU'];
            $nrorg = $this->environment->getNrOrg();
    
            $result = $this->parceiroService->validaFormaComunica($formacomu, $nrorg);
            
            $response->addDataSet(new DataSet("validaFormaComunica", array("dados" => $result)));

        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    /* Valida se existe cargo antes da inserção de um novo cargo */
    public function validaCargo(DTO\Request $request, DTO\Response $response) {
        try{
            $row = $request->getRow();
            
            $cargo = $row['CDCARGOINTERLOC'];
            $nrorg = $this->environment->getNrOrg();
    
            $result = $this->parceiroService->validaCargo($cargo, $nrorg);
            
            $response->addDataSet(new DataSet("validaCargo", array("dados" => $result)));

        }
        catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
}